@@ -197,7 +197,7 @@ backf.cl <- function(formula, data, subset, point=NULL, windows, epsilon=1e-6, d
     for(j in 1:q) {
       y.tilde.bis <- yp - alpha - rowSums(g.matriz[,-j,drop=FALSE])
       for(i in 1:n.miss) {
-        we <- k.epan( (Xp[,j] - Xp[i,j]) / windows[j] )
+        we <- k.epan( (Xp[,j] - Xp[i,j]) / as.numeric(windows[j]) )
         if(degree == 0)
           g.matriz[i,j] <- sum( we * y.tilde.bis ) / sum( we )
         if(degree > 0) {
@@ -237,7 +237,7 @@ backf.cl <- function(formula, data, subset, point=NULL, windows, epsilon=1e-6, d
     for(k in 1:np){
       for(j in 1:q){
         y.tilde.bis <- yp - alpha - rowSums(g.matriz[,-j,drop=FALSE]) #- aux1
-        we <- k.epan( (Xp[,j] - mpunto[k,j]) / windows[j] )
+        we <- k.epan( (Xp[,j] - mpunto[k,j]) / as.numeric(windows[j]) )
         if(degree == 0)
           prediccion[k,j] <- sum( we * y.tilde.bis ) / sum( we )
         if(degree > 0) {
@@ -248,7 +248,8 @@ backf.cl <- function(formula, data, subset, point=NULL, windows, epsilon=1e-6, d
       }
     }
   }
-  object <- list(alpha=alpha, g.matrix=g.matriz, prediction=prediccion, Xp=Xp, yp=yp, formula=formula)
+  object <- list(alpha=alpha, g.matrix=g.matriz, prediction=prediccion, 
+                 Xp=Xp, yp=yp, formula=formula, call=cl)
   class(object) <- c("backf.cl", "backf", "list")
   return(object)
 }
@@ -535,7 +536,8 @@ backf.rob <- function(formula, data, subset, windows, point=NULL, epsilon=1e-6,
       }
     }
   }
-  object <- list(alpha=alpha,g.matrix=g.matriz, sigma.hat=sigma.hat, prediction=prediccion, type=type, Xp=Xp, yp=yp, formula=formula)
+  object <- list(alpha=alpha, g.matrix=g.matriz, sigma.hat=sigma.hat, prediction=prediccion, 
+                 type=type, Xp=Xp, yp=yp, formula=formula, call=cl)
   class(object) <- c("backf.rob", "backf", "list")
   return(object)
   # return(list(alpha=alpha,g.matrix=g.matriz, sigma.hat=sigma.hat, prediction=prediccion))
@@ -899,12 +901,14 @@ R2.rob <- function(object,...){
 #'
 #' This function returns the estimation of the intercept and also the
 #' five-number summary and the mean of the residuals for both classical and
-#' robust estimators. For the robust estimator it also returns the estimate of
-#' the residual standard error.
+#' robust estimators. For the classical estimator, it also returns the R-squared.
+#' For the robust estimator it returns a robust version of the R-squared and 
+#' the estimate of the residual standard error.
 #'
 #' @param object an object of class \code{backf}, a result of a call to
 #' \code{\link{backf.cl}} or \code{\link{backf.rob}}.
 #' @param ... additional other arguments. Currently ignored.
+#' 
 #'
 #' @author Alejandra Mercedes Martinez \email{ale_m_martinez@hotmail.com}
 #'
@@ -916,21 +920,59 @@ summary.backf <- function(object,...){
 
 #' @export
 summary.backf.cl <- function(object,...){
-  message("Estimate of the intercept: ", round(object$alpha,5))
-  message("Multiple R-squared: ", round(R2(object),5))
-  res <- residuals(object)
-  message("Residuals:")
-  summary(res)
+  #message("Estimate of the intercept: ", round(object$alpha,5))
+  #message("Multiple R-squared: ", round(R2(object),5))
+  #res <- residuals(object)
+  #message("Residuals:")
+  #summary(res)
+  sal <- list(
+    intercept=round(object$alpha,5),
+    R2=round(R2(object),5),
+    residuals=summary(residuals(object)),
+    call = object$call
+  )
+  class(sal) <- c("summary.backf", "summary.backf.cl")
+  return(sal)
 }
 
 #' @export
 summary.backf.rob <- function(object,...){
-  message("Estimate of the intercept: ", round(object$alpha,5))
-  message("Estimate of the residual standard error: ", round(object$sigma,5))
-  message("Robust multiple R-squared: ", round(R2.rob(object),5))
-  res <- residuals(object)
-  message("Residuals:")
-  summary(res)
+  sal <- list(
+    intercept=round(object$alpha,5),
+    rse=round(object$sigma,5),
+    R2=round(R2.rob(object),5),
+    residuals=summary(residuals(object)),
+    call = object$call
+  )
+  class(sal) <- c("summary.backf", "summary.backf.rob")
+  return(sal)
+}
+
+#' @export
+#' @aliases print.summary.backf print.summary.backf.cl print.summary.backf.rob
+print.summary.backf <- function(x,...){
+  NextMethod()
+}
+
+#' @export
+print.summary.backf.cl <- function(x,...){
+  cat("Estimate of the intercept: ", x$intercept, "\n")
+  cat("Multiple R-squared: ", x$R2, "\n")
+  #res <- residuals(object)
+  cat("Residuals:\n", names(x$residuals), "\n", x$residuals, "\n")
+  #summary(res)
+}
+
+#' @export
+print.summary.backf.rob <- function(x,...){
+  cat("\nCall:\n", paste(deparse(x$call), sep = "\n", 
+                         collapse = "\n"), "\n\n", sep = "")
+  cat("Estimate of the intercept: ", x$intercept, "\n")
+  cat("Estimate of the residual standard error: ", x$rse, "\n")
+  cat("Robust multiple R-squared: ", x$R2, "\n")
+  #res <- residuals(object)
+  cat("Residuals:\n", names(x$residuals), "\n", x$residuals, "\n")
+  #summary(res)
 }
 
 #' Deviance for objects of class \code{backf}
@@ -1010,8 +1052,9 @@ formula.backf <- function(x, ...){
 #'
 #' @export
 print.backf <- function(x, ...){
-  cat("Formula:\n")
-  print(x$formula)
-  #cat("\n")
+  cat("\nCall:\n", paste(deparse(x$call), sep = "\n", 
+                         collapse = "\n"), "\n\n", sep = "")
+  cat("\n")
+  invisible(x)
 }
 
